==> stagexl_spine-0.9.0+1.tar.gz: lib/src/animation/animation_state_data.dart <==
/******************************************************************************
 * Spine Runtimes Software License v2.5
 *
 * Copyright (c) 2013-2016, Esoteric Software
 * All rights reserved.
 *
 * You are granted a perpetual, non-exclusive, non-sublicensable, and
 * non-transferable license to use, install, execute, and perform the Spine
 * Runtimes software and derivative works solely for personal or internal
 * use. Without the written permission of Esoteric Software (see Section 2 of
 * the Spine Software License Agreement), you may not (a) modify, translate,
 * adapt, or develop new applications using the Spine Runtimes or otherwise
 * create derivative works or improvements of the Spine Runtimes or (b) remove,
 * delete, alter, or obscure any trademarks or any copyright, trademark, patent,
 * or other intellectual property or proprietary rights notices on or in the
 * Software, including any copy thereof. Redistributions in binary or source
 * form must include this license and terms.
 *
 * THIS SOFTWARE IS PROVIDED BY ESOTERIC SOFTWARE "AS IS" AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL ESOTERIC SOFTWARE BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES, BUSINESS INTERRUPTION, OR LOSS OF
 * USE, DATA, OR PROFITS) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER
 * IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *****************************************************************************/

part of stagexl_spine;

class AnimationStateData {

  final SkeletonData skeletonData;
  final Map<String, num> animationToMixTime = new Map<String, num>();
  double defaultMix = 0.0;

  AnimationStateData(this.skeletonData);

  void setMixByName(String fromName, String toName, double duration) {
    Animation from = this.skeletonData.findAnimation(fromName);
    if (from == null) throw new ArgumentError("Animation not found: $fromName");
    Animation to = this.skeletonData.findAnimation(toName);
    if (to == null) throw new ArgumentError("Animation not found: $toName");
    setMix(from, to, duration);
  }

  void setMix(Animation from, Animation to, double duration) {
    if (from == null) throw new ArgumentError("from cannot be null.");
    if (to == null) throw new ArgumentError("to cannot be null.");
    animationToMixTime["${from.name}:${to.name}"] = duration;
  }

  double getMix(Animation from, Animation to) {
    double time = animationToMixTime["${from.name}:${to.name}"];
    return time is double ? time : defaultMix;
  }
}

==> stagexl_spine-0.10.1.tar.gz: lib/src/animation/animation_state_data.dart <==
/******************************************************************************
 * Spine Runtimes Software License v2.5
 *
 * Copyright (c) 2013-2016, Esoteric Software
 * All rights reserved.
 *
 * You are granted a perpetual, non-exclusive, non-sublicensable, and
 * non-transferable license to use, install, execute, and perform the Spine
 * Runtimes software and derivative works solely for personal or internal
 * use. Without the written permission of Esoteric Software (see Section 2 of
 * the Spine Software License Agreement), you may not (a) modify, translate,
 * adapt, or develop new applications using the Spine Runtimes or otherwise
 * create derivative works or improvements of the Spine Runtimes or (b) remove,
 * delete, alter, or obscure any trademarks or any copyright, trademark, patent,
 * or other intellectual property or proprietary rights notices on or in the
 * Software, including any copy thereof. Redistributions in binary or source
 * form must include this license and terms.
 *
 * THIS SOFTWARE IS PROVIDED BY ESOTERIC SOFTWARE "AS IS" AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL ESOTERIC SOFTWARE BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES, BUSINESS INTERRUPTION, OR LOSS OF
 * USE, DATA, OR PROFITS) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER
 * IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *****************************************************************************/

part of stagexl_spine;

class AnimationStateData {
  final SkeletonData skeletonData;
  final Map<String, num> animationToMixTime = Map<String, num>();
  double defaultMix = 0.0;

  AnimationStateData(this.skeletonData);

  void setMixByName(String fromName, String toName, double duration) {
    Animation from = this.skeletonData.findAnimation(fromName);
    if (from == null) throw ArgumentError("Animation not found: $fromName");
    Animation to = this.skeletonData.findAnimation(toName);
    if (to == null) throw ArgumentError("Animation not found: $toName");
    setMix(from, to, duration);
  }

  void setMix(Animation from, Animation to, double duration) {
    if (from == null) throw ArgumentError("from cannot be null.");
    if (to == null) throw ArgumentError("to cannot be null.");
    animationToMixTime["${from.name}:${to.name}"] = duration;
  }

  double getMix(Animation from, Animation to) {
    double time = animationToMixTime["${from.name}:${to.name}"];
    return time is double ? time : defaultMix;
  }
}
